@@ -133,6 +133,9 @@ class ConvertXmindToExcel:
         for i in range(self.index + 1):
             content = content_array[i]
             content = content.replace('\b', '')
+            if content is None:
+                print(f'存在空节点，请检查{content_array}中是否存在空')
+                raise Exception('存在空节点')
             is_prop, column_name, column_value = self.check_in_column(content)
             if is_prop:
                 # 如果content以 "列名："的样式开开头，则进入对应的列名解析
